// -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-

//    Focused window indicator
//    Puts icon and title of the current window in the gnome shell top panel
//
//    ----------------------------------------------------------------------
//    Copyright © 2018  Pellegrino Prevete
//
//    All rights reserved
//    ----------------------------------------------------------------------
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <https://www.gnu.org/licenses/>.

const St = imports.gi.St;
const Clutter = imports.gi.Clutter;
const Main = imports.ui.main;
const Shell = imports.gi.Shell;

let icon;
let label;
let focusWindowNotifyConnection = null;
let windowTitleNotifyConnection = null;
let window = null;


function init(metadata) {
    log('Extension initialized');

    _focusedWindowIndicator = new St.BoxLayout({style_class: 'panel-button'});
    icon = new St.Bin();
    label = new St.Label({y_align: Clutter.ActorAlign.CENTER});

    _focusedWindowIndicator.add_child(icon)
    _focusedWindowIndicator.add_child(label)
}

function set_window_indicator() {
    if(!window)
        return;
    
    let windowTitle = window.get_title();
    label.set_text(windowTitle);

    let app = Shell.WindowTracker.get_default().get_window_app(window);
    let iconName = app.app_info.get_icon().names[0];
    icon.child = new St.Icon({ icon_name: iconName + '-symbolic',
                               style_class: 'system-status-icon' });
}

function on_focus_window_notify() {
    if((windowTitleNotifyConnection)&&(window))
    	window.disconnect(windowTitleNotifyConnection);
    
    window = global.display.get_focus_window();
    
    if(!window)
    	return;
    
    windowTitleNotifyConnection = window.connect("notify::title",
    		                                    set_window_indicator);
    set_window_indicator();
}

function enable() {
    log ('Example extension enabled');

    Main.panel._leftBox.insert_child_at_index(_focusedWindowIndicator, 1);

    focusWindowNotifyConnection = global.display.connect('notify::focus-window', on_focus_window_notify);
    on_focus_window_notify();
}

function disable() {
    log ('Example extension disabled');

    global.display.disconnect(focusWindowNotifyConnection);
    
    Main.panel._leftBox.remove_actor(_focusedWindowIndicator)
}
